@@ -15,7 +15,7 @@ use vars qw($VERSION $err $errstr $state $sqlstate $drh $i $j $dbcnt);
 #@EXPORT = qw(
 	
 #);
-$VERSION = '0.06';
+$VERSION = '0.08';
 
 # Preloaded methods go here.
 
@@ -56,13 +56,13 @@ $DBD::LDAP::dr::imp_data_size = 0;
 
 sub connect
 {
-    my($drh, $dbname, $dbuser, $dbpswd, $attr, $old_driver, $connect_meth) = @_;
-    my($i, $j);
+	my($drh, $dbname, $dbuser, $dbpswd, $attr, $old_driver, $connect_meth) = @_;
+	my($i, $j);
 
-    # Avoid warnings for undefined values
+	# Avoid warnings for undefined values
 
-    $dbuser ||= '';
-    $dbpswd ||= '';
+	$dbuser ||= '';
+	$dbpswd ||= '';
 
 	$ENV{LDAP_HOME} ||= '';
 	unless (open(DBFILE, "<$ENV{LDAP_HOME}/${dbname}.ldb"))
@@ -83,7 +83,11 @@ sub connect
 	}
 	while (/^\#/);
 
+	s#^(\w+)\:\/\/#$1\x02\/\/#;  #PROTECT COLON IN PROTOCOLS (ADDED ON)
+	s#\:(\d+)#\x02$1#g;         #PROTECT COLON BEFORE PORT#S (ADDED ON)
 	my ($ldap_hostname, $ldap_root, $ldap_loginrule) = split(/\:/);
+	$ldap_hostname =~ s/\x02/\:/go;
+
 	my %ldap_tables;
 	my %ldap_ops;
 	my ($tablename,$basedn,$dnattbs,$inseparator,$outseparator);
@@ -102,7 +106,7 @@ sub connect
 		eval "\$ldap_ops{$tablename} = \{$dbdattbs\};";
 	}
 
-    #CREATE A 'BLANK' DBH
+	#CREATE A 'BLANK' DBH
 
 	if ($dbuser && $ldap_loginrule =~ /\*/)
 	{
@@ -111,29 +115,42 @@ sub connect
 		$dbuser = $ldap_loginrule;
 		$dbuser =~ s/\*/$_/g;
 	}
-    my ($privateattr) = 
-    {
+	my ($privateattr) = 
+	{
 		'Name' => $ldap_hostname,
-		'user' => $dbuser,
-		'dbpswd' => $dbpswd
-    };
+				'user' => $dbuser,
+				'dbpswd' => $dbpswd
+	};
 
-    my $this = DBI::_new_dbh($drh, 
-    {
-    		'Name' => $ldap_hostname,              #LDAP URL!
-    		'USER' => $dbuser,              #OPTIONAL, '' = ANONYMOUS!	
-    		'CURRENT_USER' => $dbuser,
-    });
+	my $this = DBI::_new_dbh($drh, 
+	{
+		'Name' => $ldap_hostname,              #LDAP URL!
+				'USER' => $dbuser,              #OPTIONAL, '' = ANONYMOUS!	
+		'CURRENT_USER' => $dbuser,
+	}
+	);
 
 	my $ldap_hostport = 389;
 	$ldap_hostport = $1  if ($ldap_hostname =~ s/\;(.*)$//);
-	my $ldap = Net::LDAP->new($ldap_hostname, port => $ldap_hostport);
+	my $ldap;
+	my @connectArgs = ($ldap_hostname);
+	push (@connectArgs, 'port', $ldap_hostport)  unless ($ldap_hostname =~ /\:\d+$/);
+	if ($ldap_hostname =~ /^ldaps/)
+	{
+		unless (defined($attr->{ldaps_capath}) && -d $attr->{ldaps_capath})
+		{
+			DBI::set_err($drh, -1, "Must specify valid path for \"ldaps_capath\" attribute when using ldaps!");
+			return undef;
+		}
+		push (@connectArgs, 'verify', 'require', 'capath', $attr->{ldaps_capath});
+	}
+	$ldap = Net::LDAP->new(@connectArgs);
 	unless ($ldap)
 	{
 		DBI::set_err($drh, -1, "Could not connect to \"$ldap_hostname\" (".$@.")!");
 		return undef;
 	}
-	
+
 	my $mesg;
 	if ($dbpswd)
 	{
@@ -303,6 +320,8 @@ sub prepare
 			if ($resptr->{ldap_attrhref}->{ldap_inseparator});
 	$myldapref->{ldap_outseparator} = $resptr->{ldap_attrhref}->{ldap_outseparator} 
 			if ($resptr->{ldap_attrhref}->{ldap_outseparator});
+	$myldapref->{ldap_appendbase2ins} = $resptr->{ldap_attrhref}->{ldap_appendbase2ins}
+			? $resptr->{ldap_attrhref}->{ldap_appendbase2ins} : 0;
 
 	$sqlstr =~ /(into|from|update|table) \s*(\w+)/gi;
 	my ($tablename) = $2;
@@ -580,6 +599,7 @@ sub execute
 	{
 		$retval = $resv[0];
 		my $dB = $sth->{Database};
+
 		if ($dB->FETCH('AutoCommit') == 1 && $sth->FETCH('Statement') !~ /^\s*select/i)
 		{
 			$dB->STORE('AutoCommit',0);  #ADDED 20010911 AS PER SPRITE TO MAKE AUTOCOMMIT WORK.
@@ -599,6 +619,7 @@ sub execute
 	#EVERYTHING WORKED, SO SAVE LDAP RESULT (# ROWS) AND FETCH FIELD INFO.
 	
     $sth->{'driver_rows'} = $resv[0]; # number of rows
+    $sth->{'ldap_rows'} = $resv[0]; # number of rows    #ADDED 20050416 PER PACH BY jmorano
 
     #### NOTE #### IF THIS FAILS, IT PROBABLY NEEDS TO BE "ldap_rows"?
     
@@ -611,15 +632,15 @@ sub execute
 		@{$ldapref->{NAME}} = @l;
 		for my $i (0..$#l)
 		{
-			#${$ldapref->{TYPE}}[$i] = $typehash{${$ldapref->{types}}{$l[$i]}};
-			#${$ldapref->{PRECISION}}[$i] = ${$ldapref->{lengths}}{$l[$i]};
-			#${$ldapref->{SCALE}}[$i] = ${$ldapref->{scales}}{$l[$i]};
-			#${$ldapref->{NULLABLE}}[$i] = 1;
-			#${$ldapref->{TYPE}}[$i] = 12;   #VARCHAR
-			${$ldapref->{TYPE}}[$i] = -1;   #VARCHAR
-			${$ldapref->{PRECISION}}[$i] = 255;
-			${$ldapref->{SCALE}}[$i] = 0;
+			${$ldapref->{TYPE}}[$i] = $typehash{${$ldapref->{types}}{$l[$i]}};
+			${$ldapref->{PRECISION}}[$i] = ${$ldapref->{lengths}}{$l[$i]};
+			${$ldapref->{SCALE}}[$i] = ${$ldapref->{scales}}{$l[$i]};
 			${$ldapref->{NULLABLE}}[$i] = 1;
+			#${$ldapref->{TYPE}}[$i] = 12;   #VARCHAR
+			##${$ldapref->{TYPE}}[$i] = -1;   #VARCHAR   #NEXT 4 REPLACED BY 1ST 4 PER REQUEST BY jmorano.
+			##${$ldapref->{PRECISION}}[$i] = 255;
+			##${$ldapref->{SCALE}}[$i] = 0;
+			##${$ldapref->{NULLABLE}}[$i] = 1;
 		}
 	}
 
@@ -739,11 +760,11 @@ __END__
 
 =head1 AUTHOR
 
-    This module is Copyright (C) 2000 by
+    This module is Copyright (C) 2000-2004 by
 
 		Jim Turner
 		
-        Email: jim.turner@lmco.com
+        Email:  turnerjw@wwol.com
 
     All rights reserved	Without Prejudice.
 
@@ -789,8 +810,6 @@ standard LDAP databases to Perl's database-independent database interface.
 You will need access to an existing LDAP database or set up your own using 
 an LDAP server, ie. "OpenLDAP", see (http://www.openldap.org).  
 
-JLdap.pm is included in this module as a separate file, and is required.
-
 The main advantage of DBD::LDAP is the ability to query LDAP databases via 
 standard SQL queries in leu of cryptic LDAP "filters".  LDAP is optimized for 
 quick lookup of existing data, but DBD::LDAP does support entry inserts, 
@@ -819,7 +838,11 @@ display all "person"s with a "dn" containing ""ou=Widgets, dc=Acme, dc=com".
     Installing this module (and the prerequisites from above) is quite
     simple. You just fetch the archive, extract it with
 
-        gzip -cd DBD-LDAP-0.1000.tar.gz | tar xf -
+        gzip -cd DBD-LDAP-####.tar.gz | tar xf -
+
+		-or-
+
+		tar -xzvf DBD-LDAP-####.tar.gz
 
     (this is for Unix users, Windows users would prefer WinZip or something
     similar) and then enter the following:
@@ -835,8 +858,7 @@ display all "person"s with a "dn" containing ""ou=Widgets, dc=Acme, dc=com".
 
     Note that you almost definitely need root or administrator permissions.
     If you don't have them, read the ExtUtils::MakeMaker man page for
-    details on installing in your own directories. the ExtUtils::MakeMaker
-    manpage.
+    details on installing in your own directories. 
 
 
 =head1 GETTING STARTED:
